﻿/*----------------------------------------------------------------------------

  EXEpress Extension Module SDK Header

  Version 3.00

  Copyright (C) 1998-2021 Web Technology Corp.
  Copyright (C) CRI Middleware Co., Ltd.

----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------
    ホスト提供関数タイプ宣言
----------------------------------------------------------------------------*/
typedef HGLOBAL (WINAPI *EXEPRESS_EXTRACTFILEW)(LPCWSTR); // ファイル解凍
typedef HGLOBAL (WINAPI *EXEPRESS_EXTRACTFILE)(LPCSTR); // ファイル解凍
typedef BOOL (WINAPI *EXEPRESS_REGISTERINSTALLEDFILEW)(LPCWSTR); // アンインストール対象登録
typedef BOOL (WINAPI *EXEPRESS_REGISTERINSTALLEDFILE)(LPCSTR); // アンインストール対象登録

/*----------------------------------------------------------------------------
    コールバック情報構造体
----------------------------------------------------------------------------*/
#include <pshpack1.h>
typedef struct
{
    DWORD dwSize;           // 構造体サイズ
    INT nPhase;             // 現在の処理内容

    HWND hWnd;              // ウィザード／アンインストーラウィンドウのハンドル。EPEXT_INITIALIZE または EPEXT_UNINST_INITIALIZE の場合 NULL
    LPCSTR lpszDialogTitle; // ウィザード／アンインストーラウィンドウのタイトル文字列
    LPCSTR lpszExeFile;     // 自己解凍実行ファイル名／アンインストーラ実行ファイル名のパス

    LPCSTR lpszInfoFile;    // 拡張情報の入ったファイルのパス。システムの一時ファイル名となる点に注意。使わない場合 NULL
                            // ※アンインストーラ用拡張モジュールでは使用不可能

    LPARAM lParam1;         // 以下、処理内容に依存するパラメータ
    LPARAM lParam2;
    LPARAM lParam3;
    LPARAM lParam4;

    LPARAM lUserParam;      // このパラメータは DLL 側で自由に使用可能

    // 本体から提供されている機能を呼び出す関数

    // ファイル解凍
    // ※アンインストーラ用拡張モジュールでは使用不可能
    EXEPRESS_EXTRACTFILE lpfnExtractFile;

    // アンインストール対象として登録
    // ※EPEXT_EXTRACT_COMPLETE内で使用可能
    // ※アンインストーラ用拡張モジュールでは使用不可能
    EXEPRESS_REGISTERINSTALLEDFILE lpfnRegisterInstalledFile;
} EXEPRESSEXTENSION_INFO;
#include <poppack.h>
#include <pshpack1.h>
typedef struct
{
    DWORD dwSize;           // 構造体サイズ
    INT nPhase;             // 現在の処理内容

    HWND hWnd;              // ウィザード／アンインストーラウィンドウのハンドル。EPEXT_INITIALIZE または EPEXT_UNINST_INITIALIZE の場合 NULL
    LPCWSTR lpszDialogTitle; // ウィザード／アンインストーラウィンドウのタイトル文字列
    LPCWSTR lpszExeFile;     // 自己解凍実行ファイル名／アンインストーラ実行ファイル名のパス

    LPCWSTR lpszInfoFile;    // 拡張情報の入ったファイルのパス。システムの一時ファイル名となる点に注意。使わない場合 NULL
                            // ※アンインストーラ用拡張モジュールでは使用不可能

    LPARAM lParam1;         // 以下、処理内容に依存するパラメータ
    LPARAM lParam2;
    LPARAM lParam3;
    LPARAM lParam4;

    LPARAM lUserParam;      // このパラメータは DLL 側で自由に使用可能

    // 本体から提供されている機能を呼び出す関数

    // ファイル解凍
    // ※アンインストーラ用拡張モジュールでは使用不可能
    EXEPRESS_EXTRACTFILEW lpfnExtractFile;

    // アンインストール対象として登録
    // ※EPEXT_EXTRACT_COMPLETE内で使用可能
    // ※アンインストーラ用拡張モジュールでは使用不可能
    EXEPRESS_REGISTERINSTALLEDFILEW lpfnRegisterInstalledFile;
} EXEPRESSEXTENSION_INFOW;
#include <poppack.h>

/*----------------------------------------------------------------------------
    nPhase の定数。未知の値を渡された場合は EPEXTRET_NOERROR を返すこと
----------------------------------------------------------------------------*/

// 自己解凍実行ファイル用拡張モジュールの場合
#define EPEXT_INITIALIZE                1000    // 自己解凍起動時、ウィザード表示前。パラメータ未使用
#define EPEXT_AFTER_FIRSTPAGE           1001    // ウィザード最初のページが表示され、「次へ」を押した直後。パラメータ未使用
#define EPEXT_PATHDETERMINED            1006    // 「解凍先フォルダ」を入力して「次へ」を押した直後。lParam1が解凍先フォルダのフルパス
#define EPEXT_BEFORE_EXTRACT            1002    // ファイル解凍前。lParam1がファイル名（解凍後フルパス）lParam2がファイル名（アーカイブ内）
#define EPEXT_AFTER_EXTRACT             1003    // ファイル解凍後。lParam1がファイル名（解凍後フルパス）lParam2がファイル名（アーカイブ内）
#define EPEXT_EXTRACT_COMPLETE          1008    // すべてのファイル解凍が完了した後。パラメータ未使用
#define EPEXT_QUERYREBOOT               1005    // 自己解凍終了時、Windowsの再起動が必要かどうかの問い合わせ。lParam1が0以外なら、EXEpress側では再起動を必要としている
#define EPEXT_BEFORE_EXECUTE            1004    // 全処理完了、後処理プログラム起動前。パラメータ未使用
#define EPEXT_ABORTED                   1007    // 処理途中に何らかの原因で処理が中断した。lParam1にエラーコード

// アンインストーラ用拡張モジュールの場合
#define EPEXT_UNINST_INITIALIZE         2000    // アンインストーラ起動時、ダイアログボックス表示前。パラメータ未使用
#define EPEXT_UNINST_START_UNINSTALL    2003    // ファイル削除の開始直前。パラメータ未使用
#define EPEXT_UNINST_QUERYREBOOT        2002    // アンインストーラ終了時、Windowsの再起動が必要かどうかの問い合わせ。lParam1が0以外なら、EXEpress側では再起動を必要としている
#define EPEXT_UNINST_FINALIZE           2001    // 全処理完了、アンインストーラプロセスが終了する直前。パラメータ未使用

/*----------------------------------------------------------------------------
    コールバックの戻り値（未定義値は EPEXTRET_ERROR として扱われる）
----------------------------------------------------------------------------*/
#define EPEXTRET_NOERROR        0               // エラー無し
#define EPEXTRET_ERROR          1               // エラー発生、プログラム終了
#define EPEXTRET_SKIP           2               // 処理をスキップ。EPEXT_BEFORE_EXTRACTで使用
#define EPEXTRET_RETRY          3               // 処理をやり直し。EPEXT_AFTER_FIRSTPAGEまたはEPEXT_PATHDETERMINEDで使用
#define EPEXTRET_NEEDREBOOT     4               // Windowsの再起動要求を表示する。EPEXT_QUERYREBOOTまたはEPEXT_UNINST_QUERYREBOOTで使用
#define EPEXTRET_NONEEDREBOOT   5               // Windowsの再起動要求を表示しない。EPEXT_QUERYREBOOTまたはEPEXT_UNINST_QUERYREBOOTで使用
#define EPEXTRET_EXECUTESILENT  6               // 自己解凍実行プログラムをサイレントモードで実行する。EPEXT_INITIALIZEで使用

/*----------------------------------------------------------------------------
    エラーコード（EPEXT_ABORTEDのlParam1に格納される値）
----------------------------------------------------------------------------*/
#define EP_ABORT_USERCANCEL         -1          // ユーザーが処理をキャンセルした
#define EP_ABORT_SFXHEADER          1           // 自己解凍実行ファイルのデータヘッダに問題がある
#define EP_ABORT_MEMORY             2           // メモリが不足している
#define EP_ABORT_ARCHIVEHEADER      3           // 圧縮データ（CAB）のヘッダに問題がある
#define EP_ABORT_NOSUPPORTFORMAT    4           // CAB内に未対応形式の圧縮データが見つかった
#define EP_ABORT_NOSUPPORTMETHOD    5           // CAB内に未対応形式の圧縮メソッドが見つかった
#define EP_ABORT_CRC                6           // CRCチェックに失敗した
#define EP_ABORT_CREATEFILE         7           // ファイル作成に失敗した
#define EP_ABORT_FILEWRITE          8           // ファイルへの書き込みに失敗した
#define EP_ABORT_CREATEFOLDER       9           // フォルダ作成に失敗した
#define EP_ABORT_UNKNOWN            10          // 原因不明のエラーが発生した
#define EP_ABORT_INVALIDPATH        11          // フォルダまたはファイルのパス名が不正だった

/*----------------------------------------------------------------------------
    コールバック関数宣言
----------------------------------------------------------------------------*/
#ifdef __cplusplus
extern "C" {
#endif
INT WINAPI EXEpressExtension(EXEPRESSEXTENSION_INFO*);
INT WINAPI EXEpressExtensionW(EXEPRESSEXTENSION_INFOW*);
#ifdef __cplusplus
} // extern "C"
#endif
